@@ -1,6 +1,10 @@
 # Copyright (c) 2021 Mark Crowe <https://github.com/markcrowe-com>. All rights reserved.
 
 from IPython.core.display import display, HTML
+import os
+
+GITHUB_RAW_QUERY_STRING = '?raw=true'
+RELATIVE_PATH = './..'
 
 
 def create_jupyter_notebook_header(github_username: str, repository: str, notebook_filepath: str, branch: str = 'master', style: str = 'style="margin: auto;"') -> str:
@@ -12,9 +16,11 @@ def create_jupyter_notebook_header(github_username: str, repository: str, notebo
     :param branch: branch name
     :return: HTML header
     """
+
+    html_comment = f'''<!--{os.linesep}import data_analytics.github as github{os.linesep}print(github.create_jupyter_notebook_header("{github_username}", "{repository}", "{notebook_filepath}", "{branch}")){os.linesep}-->{os.linesep}'''
     binder_url = f'https://mybinder.org/v2/gh/{github_username}/{repository}/{branch}?filepath={notebook_filepath}'
     colab_url = f'https://colab.research.google.com/github/{github_username}/{repository}/blob/{branch}/{notebook_filepath}'
-    return f'<table {style}><tr><td><a href="{binder_url}" target="_parent"><img src="https://mybinder.org/badge_logo.svg" alt="Open In Binder"/></a></td><td>online editors</td><td><a href="{colab_url}" target="_parent"><img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab"/></a></td></tr></table>'
+    return f'{html_comment}<table {style}><tr><td><a href="{binder_url}" target="_parent"><img src="https://mybinder.org/badge_logo.svg" alt="Open In Binder"/></a></td><td>online editors</td><td><a href="{colab_url}" target="_parent"><img src="https://colab.research.google.com/assets/colab-badge.svg" alt="Open In Colab"/></a></td></tr></table>'
 
 
 def display_jupyter_notebook_data_sources(datasource_filenames: list) -> None:
@@ -41,6 +47,13 @@ def display_jupyter_notebook_header(github_username: str, repository: str, noteb
         github_username, repository, notebook_filepath, branch)))
 
 
+def get_filepath(repository_url: str, filename: str, is_remote: bool = True, relative_path: str = RELATIVE_PATH, query_string: str = GITHUB_RAW_QUERY_STRING) -> str:
+    if is_remote:
+        return f'{repository_url}/{filename}{query_string}'
+    else:
+        return f'{relative_path}/{filename}'
+
+
 def get_github_url(repository_url: str, filename: str) -> str:
     """
     Get GitHub URL
@@ -71,3 +84,27 @@ def print_jupyter_notebook_header_html(github_username: str, repository: str, no
     """
     print(create_jupyter_notebook_header(
         github_username, repository, notebook_filepath, branch))
+
+
+class RepositoryFileManager:
+    """
+    A RepositoryFileManager is a class that manages the filepaths for a GitHub repository.
+    """
+
+    def __init__(self, repository_url: str, relative_path: str = RELATIVE_PATH, is_remote: bool = False):
+        """
+        Initialize a RepositoryFileManager
+        :param repository_url: GitHub repository URL
+        :param relative_path: relative path to use to access the files
+        :param is_remote: is the repository remote
+        """
+        self.is_remote = is_remote
+        self.relative_path = relative_path
+        self.repository_url = repository_url
+        self.query_string = GITHUB_RAW_QUERY_STRING
+
+    def get_repository_filepath(self, filename: str) -> str:
+        """
+        Get the filepath for a file in the repository
+        """
+        return get_filepath(self.repository_url, filename, self.is_remote, self.relative_path, self.query_string)
